﻿/*
   Copyright 2013 uraku.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using SStoEbook.Convert;
using System.IO;

namespace SStoEbook
{
    /// <summary>
    /// SS to e-book のメインフォームクラス
    /// </summary>
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
        }

        private void ButtonConvert_Click(object sender, EventArgs e)
        {
            String convertBeforeText = TextConvertBefore.Text;
            TextConverter converter = new TextConverter();
            String convertAfterText = converter.Convert(convertBeforeText);
            TextConvertAfter.Text = convertAfterText;
        }

        private void ButtonBeforeCrear_Click(object sender, EventArgs e)
        {
            TextConvertBefore.Text = "";
        }

        private void ButtonAfterCrear_Click(object sender, EventArgs e)
        {
            TextConvertAfter.Text = "";
        }

        private void TextConvertBefore_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == System.Windows.Forms.Keys.A & e.Control == true)
            {
                TextConvertBefore.SelectAll();
            }
        }

        private void TextConvertAfter_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == System.Windows.Forms.Keys.A & e.Control == true)
            {
                TextConvertAfter.SelectAll();
            }
        }

        private void ButtonBeforePaste_Click(object sender, EventArgs e)
        {
            IDataObject data = Clipboard.GetDataObject();
            if (data != null && data.GetDataPresent(DataFormats.Text) == true)
            {
                TextConvertBefore.Paste();
            }
        }

        /// <summary>
        /// 変換結果をテキストファイルに保存する
        /// </summary>
        /// <param name="sender">sender</param>
        /// <param name="e">event</param>
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            dialog.AddExtension = true;
            dialog.Filter = Message.SaveFileTypes;
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                Stream stream = dialog.OpenFile();
                if (stream != null)
                {
                    System.IO.StreamWriter sw = new System.IO.StreamWriter(stream);
                    sw.Write(TextConvertAfter.Text);
                    sw.Close();
                    stream.Close();
                }
            }
        }

        private void TextConvertBefore_TextChanged(object sender, EventArgs e)
        {
            int lines = TextConvertBefore.Lines.Length;
            LabelBeforeLines.Text = lines + Message.Line;
        }

        private void TextConvertAfter_TextChanged(object sender, EventArgs e)
        {
            int lines = TextConvertAfter.Lines.Length;
            LabelAfterLines.Text = lines + Message.Line;
        }

        private void ButtonInfo_Click(object sender, EventArgs e)
        {
            MessageBox.Show(Message.InfoText, Message.Info);
        }
    }
}
