﻿/*
   Copyright 2013 uraku.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Text.RegularExpressions;

namespace SStoEbook.Convert
{
    /// <summary>
    /// SSテキストコンバーター
    /// </summary>
    class TextConverter
    {

        public String Convert(String beforeText)
        {
            if (beforeText.Length < 1)
            {
                return "";
            }

            /* 入力文字列を1行ずつに分割 */
            String[] splitLines = beforeText.Split(new Char[] { '\n' });
            StringBuilder builder = new StringBuilder();
            bool beforeLineBreak = true;
            /* 一行ずつ改行を入れなおす */
            foreach (String line in splitLines)
            {
                StringBuilder lBDeleteBuilder = new StringBuilder(line);
                lBDeleteBuilder.Replace("\r", "");
                lBDeleteBuilder.Replace("\n", "");
                lBDeleteBuilder.Replace("\t", "");
                String noLBLine = lBDeleteBuilder.ToString();

                if (!beforeLineBreak && IsLineBreakNowLineStart(noLBLine))
                {
                    builder.Append("\r\n");
                }
                builder.Append(noLBLine);
                if (IsLineBleakNext(noLBLine))
                {
                    builder.Append("\r\n");
                    beforeLineBreak = true;
                }
                else
                {
                    beforeLineBreak = false;
                }
            }
            String outString = builder.ToString();
            if((outString.Length > 3) && (outString.EndsWith("\r\n")))
            {
                outString = outString.Substring(0, outString.Length - "\r\n".Length);
            }
            return outString;
        }

        /* 行頭で改行を行うか */
        private bool IsLineBreakNowLineStart(String line)
        {
            if (line.Length < 1)
                return true;
            if (Regex.IsMatch(line, "^[「｢『\\s　・\\-－―\\*※\\(（<＜\\[【《≪\"”\'\\{].*"))
                return true;
            if (Regex.IsMatch(line, "^[a-zA-Z0-9].*"))
                return true;
            return false;
        }

        /* 行末で改行を行うか */
        private bool IsLineBleakNext(String line)
        {
            if (line.EndsWith("。"))
                return true;
            if (line.Length < 1)            
                return true;
            return false;
        }
    }
}
